# Un vol d'une source de données confidentielle

Un des pires scénarios qui peut subvenir dans une organisation, c'est de se faire voler une source de données confidentielles. En plus de devoir gérer le risque de fraude d'identité auprès de la clientèle ainsi que la perte de propriété intellectuelle, l'entreprise doit aussi rapidement se remettre sur pied, rétablir sa réputation et adopter de meilleures pratiques. Il y aura également une remise en question de la pertinence et de l'utilisation des données accumulées dans le passé.

Les principales causes d'un vol de données sont :

- L'infection par un maliciel de type rançongiciel.
- L'intrusion depuis le réseau Internet par des menaces persistantes avancées
- Un membre du personnel mal intentionné qui obtient des privilèges par l'ingénierie sociale ou par la négligence
- L'absence de sécurisation dans l'infonuagique
- La perte d'équipement informatique

## Comment éviter cette histoire d'horreur?

Nous voulons réduire le risque de vol d'une source de données confidentielles.
Nous allons décrire quelques éléments nécessaires pour construire une bonne stratégie à ce sujet.

### Bien définir les rôles

Le premier élément, c'est de bien définir les rôles des employées et employés. Un rôle établit un groupe de tâches nécessitant, pour leur réalisation, l'utilisation d'un sous-ensemble de données. Ce modèle de gestion se nomme le contrôle d'accès basé sur les rôles, plus souvent rencontré sous l'acronyme RBAC.

Il faut ici différencier l'utilisateur du rôle. Le premier permet l'identification et l'authentification auprès d'un système informatique. Il est souvent combiné à un mot de passe. C'est celui qui est entre autres utilisé pour ouvrir une session sur l'ordinateur. Le second ne détient pas ces capacités. Cependant, il possède des droits d'accès aux données et d'exécution de certains logiciels.

Chaque utilisateur peut avoir un ou plusieurs rôles. Dans les meilleures pratiques, elles et ils n'en ont qu'un seul à la fois, ce qui permet d'éviter les croisements de données de différentes sources.

Une liste minimale de rôles dans une organisation pourrait être :

- Conseil d'administration
- Gestion
- Service informatique
- Service comptable
- Ressources humaines
- Service à la clientèle
- Approvisionnement
- Ventes

### Contrôler l'accès aux données

Voici le second élément de notre stratégie. Nous allons définir, pour chacun des rôles, à quoi ils devraient avoir accès. 

Dans une entreprise de distribution, les équipes sur la route ne devraient utiliser seulement les données de la clientèle située sur leur territoire. On effectue donc un filtrage de la base de données en utilisant la géolocalisation. C'est une forme de gestion des accès axée sur les enregistrements.

Dans un autre scénario, nous nous intéressons au service téléphonique. Son personnel ne devraient avoir accès qu'aux renseignements qu'ils ont droit de divulguer à la clientèle par la voix. Les informations qui sont communiquées entre les systèmes doivent être cachées. Par exemple, ils ne devraient pas avoir accès aux champs contenant les numéros de carte de crédit ni aux mots de passe. C'est ici une forme de gestion des accès basés sur les attributs.

Enfin, lorsque nous devons appliquer des restrictions à la fois sur des enregistrements et des colonnes, il peut être utile de créer des vues. Ce sont des requêtes formatées aux besoins du rôle et présentées sous la forme de tables.

### Utiliser le masquage de données

La réalité du monde de l'entreprise, c'est qu'il n'y a pas de solution universelle. 

Parfois, certains processus d'affaires requièrent de voir les vraies données. Par exemple, les gestionnaires des ressources humaines nécessitent d'accéder à des informations médicales ou des numéros d'assurance sociale.

De nombreux rapports et systèmes dérivés consomment des bases de données existantes, qui ne pourraient pas facilement être recréées avec les principes de gestion des accès que nous avons présentés ci-dessus. On ne veut pas tout recommencer!

Un autre aspect à considérer: en certains cas, seule une partie du champ contient de l'information sensible. Les six premiers chiffres d'une carte de crédit décrivent l'émetteur de la carte, alors que les trois premiers caractères du code postal canadien identifient une ville ou un quartier.

Dans ces situations, on aura alors recours à une méthode de masquage des données. Celle-ci permet de cacher, partiellement ou complètement, les informations contenues dans un champ.

Voici quelques exemples de masquage:

- Une adresse courriel apparaît sous la forme suivante : `xxx@domaine.com`
- Arrondir une date de naissance au mois près : `2000-04-00`
- Substituer les noms de famille par des personnages de dessins animés : `François Superman`
- Un numéro de carte de crédit présente seulement les 4 derniers chiffres : `XXXX XXXX XXXX 1234`

## Trop tard... Quoi faire, maintenant?

Tout comme avec l'attaque par rançongiciel, si elle a pu être détectée immédiatement, les premières étapes sont: limiter les accès réseau, couper l'Internet et aviser les autorités publiques.

Si l'incident a eu lieu il y a plus d'une journée, c'est vraiment trop tard pour contrer la diffusion des renseignements sur le web profond. C'est plutôt le temps de repenser sa stratégie de gestion des données et de mettre en œuvre les conseils de ce guide immédiatement. Laissez les spécialistes en cybersécurité et la police s'occuper du reste et collaborez avec ces derniers. 

Le moment venu, informez le public de l'incident que vous avez vécu et des actions que vous avez entreprises pour améliorer votre sécurité.

## Conclusion

Nous souhaitons trouver le bon équilibre dans l'utilisation de toutes les méthodes de prévention. Nous devons donc considérer que c'est toujours un compromis entre la protection de la confidentialité, de la vie privée et la valeur de la donnée qui est accessible à l'utilisateur.

La sécurité est un exercice de gestion de risques, et lorsque les incidents se produisent, c'est souvent mieux regarder en avant et se préparer pour la prochaine fois.

